aboutsummaryrefslogtreecommitdiff
path: root/src/northbridge/via/vx900/traf_ctrl.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/northbridge/via/vx900/traf_ctrl.c')
-rw-r--r--src/northbridge/via/vx900/traf_ctrl.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/northbridge/via/vx900/traf_ctrl.c b/src/northbridge/via/vx900/traf_ctrl.c
index fb151935b2..011bb4139d 100644
--- a/src/northbridge/via/vx900/traf_ctrl.c
+++ b/src/northbridge/via/vx900/traf_ctrl.c
@@ -134,8 +134,9 @@ static struct device_operations traf_ctrl_ops = {
.set_resources = pci_dev_set_resources,
.enable_resources = pci_dev_enable_resources,
.init = vx900_traf_ctr_init,
- /* Need this here, or the IOAPIC driver won't be called */
- .scan_bus = scan_static_bus,
+ /* Need this here, or the IOAPIC driver won't be called.
+ * FIXME: Technically not a LPC bus. */
+ .scan_bus = scan_lpc_bus,
};
static const struct pci_driver traf_ctrl_driver __pci_driver = {